@@ -1,14 +1,14 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2015-2020 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2015-2022 -- leonerd@leonerd.org.uk
 
 use v5.26;
-use Object::Pad 0.19;
+use Object::Pad 0.57;
 
-package Device::Chip::SSD1306::SPI4 0.10;
+package Device::Chip::SSD1306::SPI4 0.11;
 class Device::Chip::SSD1306::SPI4
-   extends Device::Chip::SSD1306;
+   :isa(Device::Chip::SSD1306);
 
 use Future::AsyncAwait;
 
@@ -54,7 +54,7 @@ method mount ( $adapter, %params )
 }
 
 # passthrough
-method power { $self->protocol->power( $_[0] ) }
+method power ( $on ) { $self->protocol->power( $on ) }
 
 method set_dc ( $dc )
 {
